pilas.actores.globoelegir.GloboElegir

Package pilas :: Package actores :: Module globoelegir :: Class GloboElegir |
[hide private]
[frames] | no frames]

# Class GloboElegir

source code

                   object --+
                            |
    estudiante.Estudiante --+
                            |
                  actor.Actor --+
                                |
                      globo.Globo --+
                                    |
                                   GloboElegir

    Representa un mensaje de globo (similar a las historietas), pero con opciones para elegir.

        >>> mensaje = u"Mi color favorito es el..."
        >>> globo = pilas.actores.GloboElegir(mensaje, [u"rojo", u"verde", u"azul"], cuando_responde_color_favorito)

    .. image:: images/actores/globo_elegir.png

    El primer argumento es el mensaje a mostrar, el segundo una lista de opciones que se ofrecerán
    y por último una función de respuesta. Que podría ser codificada así:

    .. code-block:: python

        def cuando_responde_color_favorito(respuesta):
            print "Ha seleccionado la opcion: " + respuesta

Instance Methods | [hide private]
__init__(self, texto, opciones, funcion_a_invocar, x=0, y=0, dialogo=None) Constructor del dialogo: | source code
colocar_origen_del_globo(self, x, y) Cambia el punto de referencia del globo. | source code
_obtener_area_para_el_texto(self, texto) | source code
_escribir_texto(self, texto) | source code
cuando_quieren_avanzar(self, *k) Función que se ejecuta al hacer click para avanzar o eliminar el globo. | source code
_cuando_selecciona_opcion(self, opcion) | source code
Inherited from `globo.Globo`: `eliminar` Inherited from `globo.Globo` (private): `_pintar_globo` Inherited from `actor.Actor`: `__cmp__`, `__mul__`, `__str__`, `actor_mas_cercano`, `actualizar`, `anexar`, `colisiona_con`, `colisiona_con_un_punto`, `decir`, `definir_centro`, `definir_color`, `definir_escala`, `definir_imagen`, `definir_posicion`, `definir_rotacion`, `definir_transparencia`, `destruir`, `dibujar`, `distancia_al_punto`, `distancia_con`, `duplicar`, `es_fondo`, `esta_fuera_de_la_pantalla`, `get_abajo`, `get_arriba`, `get_derecha`, `get_espejado`, `get_fijo`, `get_imagen`, `get_izquierda`, `get_rotation`, `get_scale`, `get_scale_x`, `get_scale_y`, `get_transparencia`, `get_vx`, `get_vy`, `get_x`, `get_y`, `get_z`, `imitar`, `obtener_alto`, `obtener_ancho`, `obtener_centro`, `obtener_escala`, `obtener_imagen`, `obtener_posicion`, `obtener_rotacion`, `pre_actualizar`, `set_abajo`, `set_arriba`, `set_derecha`, `set_espejado`, `set_fijo`, `set_imagen`, `set_izquierda`, `set_rotation`, `set_scale`, `set_scale_x`, `set_scale_y`, `set_transparencia`, `set_x`, `set_y`, `set_z` Inherited from `actor.Actor` (private): `_eliminar_anexados`, `_interpretar_y_convertir_posicion` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__` Inherited from `estudiante.Estudiante`: `actualizar_comportamientos`, `actualizar_habilidades`, `agregar_habilidad`, `aprender`, `eliminar_comportamientos`, `eliminar_habilidad`, `eliminar_habilidades`, `hacer`, `hacer_luego`, `obtener_habilidad`, `tiene_comportamiento`, `tiene_habilidad` Inherited from `estudiante.Estudiante` (private): `_adoptar_el_siguiente_comportamiento`

Properties | [hide private]
Inherited from `actor.Actor`: `abajo`, `alto`, `ancho`, `arriba`, `centro`, `derecha`, `escala`, `escala_x`, `escala_y`, `espejado`, `fijo`, `imagen`, `izquierda`, `rotacion`, `transparencia`, `vx`, `vy`, `x`, `y`, `z` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, texto, opciones, funcion_a_invocar, x=0, y=0, dialogo=None) (Constructor) | source code
Constructor del dialogo: :param texto: Cadena de texto que se tiene que mostrar. :param opciones: Lista de opciones a mostrar. :param funcion_a_invocar: Referencia a la función que se tiene que ejecutar cuando responde el usuario. :param x: Posición horizontal. :param y: Posición vertical. :param dialogo: Instancia del manejador de dialogos, para crear mensajes enlazados. Overrides: estudiante.Estudiante.__init__

### colocar_origen_del_globo(self, x, y) | source code
Cambia el punto de referencia del globo. :param x: Punto de referencia horizontal. :param y: Punto de referencia vertical. Overrides: globo.Globo.colocar_origen_del_globo

### cuando_quieren_avanzar(self, *k) | source code
Función que se ejecuta al hacer click para avanzar o eliminar el globo. Overrides: globo.Globo.cuando_quieren_avanzar (inherited documentation)